## Table of contents
<!-- toc -->

<!-- tocstop -->

## Usage
<!-- usage -->
```sh-session
$ npm install -g @l1x/l1x-cli-beta
$ l1x COMMAND
running command...
$ l1x (--version)
@l1x/l1x-cli-beta/1.0.1 linux-x64 node-v18.19.1
$ l1x --help [COMMAND]
USAGE
  $ l1x COMMAND
...
```
<!-- usagestop -->

## Commands
<!-- commands -->
* [`l1x account balance [ADDRESS]`](#l1x-account-balance-address)
* [`l1x account state [ADDRESS]`](#l1x-account-state-address)
* [`l1x autocomplete [SHELL]`](#l1x-autocomplete-shell)
* [`l1x contract call CONTRACT_ADDRESS FUNCTION`](#l1x-contract-call-contract_address-function)
* [`l1x contract deploy CONTRACT_OBJECT_FILE_PATH`](#l1x-contract-deploy-contract_object_file_path)
* [`l1x contract init CONTRACT_ADDRESS`](#l1x-contract-init-contract_address)
* [`l1x contract view CONTRACT_ADDRESS FUNCTION`](#l1x-contract-view-contract_address-function)
* [`l1x help [COMMAND]`](#l1x-help-command)
* [`l1x transfer TO_ADDRESS AMOUNT`](#l1x-transfer-to_address-amount)
* [`l1x tx events TX_HASH`](#l1x-tx-events-tx_hash)
* [`l1x tx receipt TX_HASH`](#l1x-tx-receipt-tx_hash)
* [`l1x update [CHANNEL]`](#l1x-update-channel)
* [`l1x wallet accounts`](#l1x-wallet-accounts)
* [`l1x wallet create`](#l1x-wallet-create)
* [`l1x wallet default ADDRESS`](#l1x-wallet-default-address)
* [`l1x wallet import PRIVATEKEY`](#l1x-wallet-import-privatekey)

## `l1x account balance [ADDRESS]`

Retrieve the balance of an L1X Wallet.

```
USAGE
  $ l1x account balance [ADDRESS] [--endpoint <value>]

ARGUMENTS
  ADDRESS  L1X Wallet Address

FLAGS
  --endpoint=<value>  [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint

DESCRIPTION
  Retrieve the balance of an L1X Wallet.

EXAMPLES
  $ l1x account balance <address>
```

_See code: [src/commands/account/balance.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/account/balance.ts)_

## `l1x account state [ADDRESS]`

Retrieve the account state (Nonce, Balance) of an L1X Wallet.

```
USAGE
  $ l1x account state [ADDRESS] [--endpoint <value>]

ARGUMENTS
  ADDRESS  L1X Wallet Address

FLAGS
  --endpoint=<value>  [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint

DESCRIPTION
  Retrieve the account state (Nonce, Balance) of an L1X Wallet.

EXAMPLES
  $ l1x account state <address>
```

_See code: [src/commands/account/state.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/account/state.ts)_

## `l1x autocomplete [SHELL]`

Display autocomplete installation instructions.

```
USAGE
  $ l1x autocomplete [SHELL] [-r]

ARGUMENTS
  SHELL  (zsh|bash|powershell) Shell type

FLAGS
  -r, --refresh-cache  Refresh cache (ignores displaying instructions)

DESCRIPTION
  Display autocomplete installation instructions.

EXAMPLES
  $ l1x autocomplete

  $ l1x autocomplete bash

  $ l1x autocomplete zsh

  $ l1x autocomplete powershell

  $ l1x autocomplete --refresh-cache
```

_See code: [@oclif/plugin-autocomplete](https://github.com/oclif/plugin-autocomplete/blob/v3.0.16/src/commands/autocomplete/index.ts)_

## `l1x contract call CONTRACT_ADDRESS FUNCTION`

Invoke a state-changing function on an L1X VM contract.

```
USAGE
  $ l1x contract call CONTRACT_ADDRESS FUNCTION --args <value> [--endpoint <value>] [--from <value>] [--fee_limit
    <value>] [--nonce <value>]

ARGUMENTS
  CONTRACT_ADDRESS  L1X VM Contract Address
  FUNCTION          Name of the contract function to be called

FLAGS
  --args=<value>       (required) [default: {}] JSON Arguments to pass to contract
  --endpoint=<value>   [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint
  --fee_limit=<value>  [default: 1] Maximum fee allowed for the transaction
  --from=<value>       L1X Wallet Address
  --nonce=<value>      Nonce value for the transaction

DESCRIPTION
  Invoke a state-changing function on an L1X VM contract.

EXAMPLES
  $ l1x contract call <contract_address> <function>
```

_See code: [src/commands/contract/call.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/contract/call.ts)_

## `l1x contract deploy CONTRACT_OBJECT_FILE_PATH`

Deploy an L1X VM Contract Object file to the L1X Network.

```
USAGE
  $ l1x contract deploy CONTRACT_OBJECT_FILE_PATH [--endpoint <value>] [--from <value>] [--fee_limit <value>]
    [--nonce <value>]

ARGUMENTS
  CONTRACT_OBJECT_FILE_PATH  Path to the L1X VM Contract Object File

FLAGS
  --endpoint=<value>   [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint
  --fee_limit=<value>  [default: 1] Maximum fee allowed for the deployment
  --from=<value>       Deployer L1X Wallet Address
  --nonce=<value>      Nonce value to be used for deployment

DESCRIPTION
  Deploy an L1X VM Contract Object file to the L1X Network.

EXAMPLES
  $ l1x contract deploy <contract_object_file_path>
```

_See code: [src/commands/contract/deploy.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/contract/deploy.ts)_

## `l1x contract init CONTRACT_ADDRESS`

Initialize an L1X VM Contract Address.

```
USAGE
  $ l1x contract init CONTRACT_ADDRESS --args <value> [--endpoint <value>] [--from <value>] [--fee_limit <value>]
    [--nonce <value>]

ARGUMENTS
  CONTRACT_ADDRESS  L1X VM Base Contract Address

FLAGS
  --args=<value>       (required) [default: {}] JSON Arguments to pass to contract
  --endpoint=<value>   [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint
  --fee_limit=<value>  [default: 1] Maximum fee allowed for the transaction
  --from=<value>       L1X Wallet Address
  --nonce=<value>      Nonce value for the transaction

DESCRIPTION
  Initialize an L1X VM Contract Address.

EXAMPLES
  $ l1x contract init <contract_address>
```

_See code: [src/commands/contract/init.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/contract/init.ts)_

## `l1x contract view CONTRACT_ADDRESS FUNCTION`

Calls a Readonly Function on an L1X VM Contract.

```
USAGE
  $ l1x contract view CONTRACT_ADDRESS FUNCTION --args <value> [--endpoint <value>] [--from <value>]

ARGUMENTS
  CONTRACT_ADDRESS  L1X VM Contract Address
  FUNCTION          Contract Function to be called

FLAGS
  --args=<value>      (required) [default: {}] JSON Arguments to pass to contract
  --endpoint=<value>  [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint
  --from=<value>      L1X Wallet Address

DESCRIPTION
  Calls a Readonly Function on an L1X VM Contract.

EXAMPLES
  $ l1x contract view <contract_address> <function>
```

_See code: [src/commands/contract/view.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/contract/view.ts)_

## `l1x help [COMMAND]`

Display help for l1x.

```
USAGE
  $ l1x help [COMMAND...] [-n]

ARGUMENTS
  COMMAND...  Command to show help for.

FLAGS
  -n, --nested-commands  Include all nested commands in the output.

DESCRIPTION
  Display help for l1x.
```

_See code: [@oclif/plugin-help](https://github.com/oclif/plugin-help/blob/v6.0.21/src/commands/help.ts)_

## `l1x transfer TO_ADDRESS AMOUNT`

Transfer L1X tokens to another wallet

```
USAGE
  $ l1x transfer TO_ADDRESS AMOUNT [--nonce <value>] [--from <value>] [--fee_limit <value>] [--endpoint
    <value>]

ARGUMENTS
  TO_ADDRESS  Receiver L1X Wallet Address
  AMOUNT      Amount of L1X tokens to be sent (e.g., 1 L1X)

FLAGS
  --endpoint=<value>   [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint
  --fee_limit=<value>  [default: 1] Maximum fee allowed for the transaction
  --from=<value>       Sender L1X Wallet Address
  --nonce=<value>      Nonce to be used for the transaction

DESCRIPTION
  Transfer L1X tokens to another wallet

EXAMPLES
  $ l1x transfer <to_address> <amount>
```

_See code: [src/commands/transfer.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/transfer.ts)_

## `l1x tx events TX_HASH`

Fetches the events of a transaction specified by its hash.

```
USAGE
  $ l1x tx events TX_HASH [--endpoint <value>]

ARGUMENTS
  TX_HASH  L1X TX Hash

FLAGS
  --endpoint=<value>  [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint

DESCRIPTION
  Fetches the events of a transaction specified by its hash.

EXAMPLES
  $ l1x tx events <tx_hash>
```

_See code: [src/commands/tx/events.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/tx/events.ts)_

## `l1x tx receipt TX_HASH`

Fetches the receipt of a transaction specified by its hash.

```
USAGE
  $ l1x tx receipt TX_HASH [--endpoint <value>]

ARGUMENTS
  TX_HASH  L1X TX Hash

FLAGS
  --endpoint=<value>  [default: https://v2-mainnet-rpc.l1x.foundation] L1X Endpoint

DESCRIPTION
  Fetches the receipt of a transaction specified by its hash.

EXAMPLES
  $ l1x tx receipt <tx_hash>
```

_See code: [src/commands/tx/receipt.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/tx/receipt.ts)_

## `l1x update [CHANNEL]`

update the l1x CLI

```
USAGE
  $ l1x update [CHANNEL] [-a] [--force] [-i | -v <value>]

FLAGS
  -a, --available        See available versions.
  -i, --interactive      Interactively select version to install. This is ignored if a channel is provided.
  -v, --version=<value>  Install a specific version.
      --force            Force a re-download of the requested version.

DESCRIPTION
  update the l1x CLI

EXAMPLES
  Update to the stable channel:

    $ l1x update stable

  Update to a specific version:

    $ l1x update --version 1.0.0

  Interactively select version:

    $ l1x update --interactive

  See available versions:

    $ l1x update --available
```

_See code: [@oclif/plugin-update](https://github.com/oclif/plugin-update/blob/v4.2.7/src/commands/update.ts)_

## `l1x wallet accounts`

List all available accounts in the wallet

```
USAGE
  $ l1x wallet accounts

DESCRIPTION
  List all available accounts in the wallet
```

_See code: [src/commands/wallet/accounts.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/wallet/accounts.ts)_

## `l1x wallet create`

Creates a new wallet/account by generating a new key pair.

```
USAGE
  $ l1x wallet create

DESCRIPTION
  Creates a new wallet/account by generating a new key pair.

EXAMPLES
  $ l1x wallet create
```

_See code: [src/commands/wallet/create.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/wallet/create.ts)_

## `l1x wallet default ADDRESS`

Set the default wallet for L1X.

```
USAGE
  $ l1x wallet default ADDRESS

ARGUMENTS
  ADDRESS  The address of the wallet to set as default.

DESCRIPTION
  Set the default wallet for L1X.

EXAMPLES
  $ l1x wallet default <address>
```

_See code: [src/commands/wallet/default.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/wallet/default.ts)_

## `l1x wallet import PRIVATEKEY`

Import a wallet by providing its private key.

```
USAGE
  $ l1x wallet import PRIVATEKEY

ARGUMENTS
  PRIVATEKEY  The private key to import in hex format.

DESCRIPTION
  Import a wallet by providing its private key.

EXAMPLES
  $ l1x wallet import <privateKey>
```

_See code: [src/commands/wallet/import.ts](https://github.com/L1X-Foundation/l1x-cli/blob/v1.0.1/src/commands/wallet/import.ts)_
<!-- commandsstop -->
